==> connector-service-1.0.0-zds-20220325.062449-8-sources.jar: com/bizvane/connectorservice/entity/zds/ZdsCouponInfo.java <==
package com.bizvane.connectorservice.entity.zds;

import java.math.BigDecimal;
import java.util.Date;

public class ZdsCouponInfo {

    //会员Id
    private String erpId;
    //券号
    private String couponCode;
    //券名称
    private String couponName;
    //线下券类型号
    private String erpCouponDefinitionCode;
    //券类型 现金、折扣 （对应的值暂时还没提供）
    private Byte preferentialType;
    //券状态 20-未使用，25-已过期，30-已使用
    private Byte couponStatus;
    //发放渠道 （对应的值暂时还没提供）
    private String sendType;
    //券创建时间（创建时间）
    private Date createDate;
    //券领取时间
    private Date getDate;
    //有效期开始时间
    private Date validDateStart;
    //有效期结束时间
    private Date validDateEnd;
    //使用时间
    private Date useTime;
    //金额
    private BigDecimal money;
    //折扣
    private BigDecimal discount;
    //核销渠道 （对应的值暂时还没提供）
    private String useFrom;
    //核销订单编号
    private String useBusinessCode;
    //核销人code
    private String useMemberCode;

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getErpCouponDefinitionCode() {
        return erpCouponDefinitionCode;
    }

    public void setErpCouponDefinitionCode(String erpCouponDefinitionCode) {
        this.erpCouponDefinitionCode = erpCouponDefinitionCode;
    }

    public Date getGetDate() {
        return getDate;
    }

    public void setGetDate(Date getDate) {
        this.getDate = getDate;
    }

    public Byte getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(Byte preferentialType) {
        this.preferentialType = preferentialType;
    }

    public Byte getCouponStatus() {
        return couponStatus;
    }

    public void setCouponStatus(Byte couponStatus) {
        this.couponStatus = couponStatus;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Date getUseTime() {
        return useTime;
    }

    public void setUseTime(Date useTime) {
        this.useTime = useTime;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public String getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(String useFrom) {
        this.useFrom = useFrom;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public String getUseMemberCode() {
        return useMemberCode;
    }

    public void setUseMemberCode(String useMemberCode) {
        this.useMemberCode = useMemberCode;
    }
}

==> connector-service-1.0.2-zds-20220323.025706-2-sources.jar: com/bizvane/connectorservice/entity/zds/ZdsCouponInfo.java <==
package com.bizvane.connectorservice.entity.zds;

import java.math.BigDecimal;
import java.util.Date;

public class ZdsCouponInfo {

    //会员Id
    private String erpId;
    //券号
    private String couponCode;
    //券名称
    private String couponName;
    //券类型 现金、折扣 （对应的值暂时还没提供）
    private String preferentialType;
    //券状态 20-未使用，25-已过期，30-已使用
    private String couponStatus;
    //发放渠道 （对应的值暂时还没提供）
    private String sendType;
    //券领取时间（创建时间）
    private Date createDate;
    //有效期开始时间
    private Date validDateStart;
    //有效期结束时间
    private Date validDateEnd;
    //使用时间
    private Date useTime;
    //金额
    private BigDecimal money;
    //折扣
    private BigDecimal discount;
    //核销渠道 （对应的值暂时还没提供）
    private String useFrom;
    //核销订单编号
    private String useBusinessCode;
    //核销人code
    private String useMemberCode;

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getPreferentialType() {
        return preferentialType;
    }

    public void setPreferentialType(String preferentialType) {
        this.preferentialType = preferentialType;
    }

    public String getCouponStatus() {
        return couponStatus;
    }

    public void setCouponStatus(String couponStatus) {
        this.couponStatus = couponStatus;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getValidDateStart() {
        return validDateStart;
    }

    public void setValidDateStart(Date validDateStart) {
        this.validDateStart = validDateStart;
    }

    public Date getValidDateEnd() {
        return validDateEnd;
    }

    public void setValidDateEnd(Date validDateEnd) {
        this.validDateEnd = validDateEnd;
    }

    public Date getUseTime() {
        return useTime;
    }

    public void setUseTime(Date useTime) {
        this.useTime = useTime;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getDiscount() {
        return discount;
    }

    public void setDiscount(BigDecimal discount) {
        this.discount = discount;
    }

    public String getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(String useFrom) {
        this.useFrom = useFrom;
    }

    public String getUseBusinessCode() {
        return useBusinessCode;
    }

    public void setUseBusinessCode(String useBusinessCode) {
        this.useBusinessCode = useBusinessCode;
    }

    public String getUseMemberCode() {
        return useMemberCode;
    }

    public void setUseMemberCode(String useMemberCode) {
        this.useMemberCode = useMemberCode;
    }
}
